<?php
/**
 * A goverment class with simplified ways...
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 * @todo		Find an interface for goverments
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class SimplifiedGoverment extends BaseFrameworkSystem implements Registerable {
	// Constants
	const STATUS_STARTER_HELP = "STARTER_HELP";

	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Clean up a little
		$this->removeSystemArray();
		$this->removeNumberFormaters();
	}

	/**
	 * Creates an instance of this goverment class by given user instance
	 *
	 * @param	$userInstance		The user instance
	 * @return	$govermentInstance	Instance of the prepared goverment instance
	 */
	public final static function createSimplifiedGoverment (ManageableAccount $userInstance) {
		// Get a new instance
		$govermentInstance = new SimplifiedGoverment();

		// Set the user instance
		$govermentInstance->setUserInstance($userInstance);

		// Return the prepared instance
		return $govermentInstance;
	}

	/**
	 * Checks wether the goverment has already payed a startup help to the
	 * current user
	 *
	 * @return	$alreadyPayed	Wether the goverment has already payed
	 */
	public function ifGovermentAlreadyPayedStartupHelp () {
		// Default is not payed
		$alreadyPayed = false;

		// Now get a search criteria and set the user's name as criteria
		$criteriaInstance = ObjectFactory::createObjectByConfiguredName('search_criteria_class');
		$criteriaInstance->addCriteria('gov_uid', $this->getUserInstance()->getUserName());
		$criteriaInstance->addCriteria('gov_activity_status', self::STATUS_STARTER_HELP);
		$criteriaInstance->setLimit(1);

		// Get a wrapper instance
		$wrapperInstance = ObjectFactory::createObjectByConfiguredName('user_gov_wrapper_class');

		// Get result back
		$resultInstance = $wrapperInstance->doSelectByCriteria($criteriaInstance);

		// Was the query fine?
		if ($resultInstance->getAffectedRows() === 1) {
			// Entry found!
			$alreadyPayed = true;
		} // END - if

		// Return the result
		return $alreadyPayed;
	}
}

// [EOF]
?>
