<?php
/**
 * General configuration. Do not touch this file! If you need different settings
 * create a config-local.php in this directory at and set your changed
 * configuration entries there.
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

// Load the class from inc/config direktory
@require_once(dirname(__FILE__) . '/classes/interfaces/class_FrameworkInterface.php');
@require_once(dirname(__FILE__) . '/classes/interfaces/registry/class_Registerable.php');
@require_once(dirname(__FILE__) . '/config/class_FrameworkConfiguration.php');

// Get a new configuration instance
$cfg = FrameworkConfiguration::createFrameworkConfiguration();

// CFG: SERVER-PATH
$cfg->definePath(dirname(dirname(__FILE__)) . '/'); // DON'T MISS THE TRAILING SLASH!!!

// CFG: BASE-URL
$cfg->setConfigEntry('base_url', $cfg->detectBaseUrl());

// CFG: DATABASE-TYPE
$cfg->defineDatabaseType('local');

// CFG: LOCAL-DB-PATH
$cfg->setConfigEntry('local_db_path', "db/");

// CFG: TIME-ZONE
$cfg->setDefaultTimezone("Europe/Berlin");

// CFG: MAGIC-QUOTES-RUNTIME
$cfg->setMagicQuotesRuntime(false);

// CFG: PHP-SCRIPT-EXTENSION
$cfg->setConfigEntry('php_extension', ".php");

// CFG: CLASS-PREFIX
$cfg->setConfigEntry('class_prefix', "class_");

// CFG: CLASS-SUFFIX
$cfg->setConfigEntry('class_suffix', ".php");

// CFG: RAW-TEMPLATE-EXTENSION
$cfg->setConfigEntry('raw_template_extension', ".tpl");

// CFG: CODE-TEMPLATE-EXTENSION
$cfg->setConfigEntry('code_template_extension', ".ctp");

// CFG: SELECTOR-PATH
$cfg->setConfigEntry('selector_path', "selector");

// CFG: APPLICATION-HELPER
$cfg->setConfigEntry('app_helper_class', "ApplicationHelper");

// CFG: LAUNCH-METHOD
$cfg->setConfigEntry('entry_method', "entryPoint");

// CFG: TEMPLATE-BASE-PATH
$cfg->setConfigEntry('tpl_base_path', "templates/"); // DON'T MISS THE TRAILING SLASH!

// CFG: LANGUAGE-BASE-PATH
$cfg->setConfigEntry('lang_base_path', "inc/language/"); // DON'T MISS THE TRAILING SLASH!

// CFG: COMPRESSOR-BASE-PATH
$cfg->setConfigEntry('compressor_base_path', "inc/classes/main/compressor/"); // DON'T MISS THE TRAILING SLASH!

// CFG: APPLICATION-PATH
$cfg->setConfigEntry('application_path', "application");

// CFG: COMPILE-OUTPUT-PATH
$cfg->setConfigEntry('compile_output_path', "templates/_compiled/"); // DON'T MISS THE TRAILING SLASH!

// CFG: TEMPLATE-ENGINE
$cfg->setConfigEntry('template_class', "WebTemplateEngine");

// CFG: DEBUG-ENGINE
$cfg->setConfigEntry('debug_class', "DebugWebOutput");

// CFG: DEFAULT-LANGUAGE
$cfg->setConfigEntry('default_lang', "de"); // A two-char language string: de for german, en for english and so on

// CFG: WEB-TEMPLATE-TYPE
$cfg->setConfigEntry('web_template_type', "html");

// CFG: EMAIL-TEMPLATE-TYPE
$cfg->setConfigEntry('email_template_type', "emails");

// CFG: CODE-TEMPLATE-TYPE
$cfg->setConfigEntry('code_template_type', "code");

// CFG: WEB-ENGINE
$cfg->setConfigEntry('web_engine', "WebOutput");

// CFG: SELECTOR-TEMPLATE-PREFIX
$cfg->setConfigEntry('tpl_selector_prefix', "selector");

// CFG: WEB-CONTENT-TYPE
$cfg->setConfigEntry('web_content_type', "text/html");

// CFG: HEADER-CHARSET
$cfg->setConfigEntry('header_charset', "utf-8");

// CFG: VALID-TEMPLATE-VARIABLE
$cfg->setConfigEntry('tpl_valid_var', "content");

// CFG: META-AUTHOR
$cfg->setConfigEntry('meta_author', "Roland H&auml;der");

// CFG: META-PUBLISHER
$cfg->setConfigEntry('meta_publisher', "Roland H&auml;der");

// CFG: META-KEYWORDS
$cfg->setConfigEntry('meta_keywords', "test,test,test");

// CFG: META-DESCRIPTION
$cfg->setConfigEntry('meta_description', "A lame description for an application framework");

// CFG: SELECTOR-MAIN-TEMPLATE
$cfg->setConfigEntry('selector_main_tpl', "selector_main");

// CFG: SELECTOR-APPS-TEMPLATE
$cfg->setConfigEntry('selector_apps_tpl', "selector_apps");

// CFG: SELECTOR-NAME
$cfg->setConfigEntry('selector_name', "selector");

// CFG: DEFAULT-APPLICATION
$cfg->setConfigEntry('default_application', "selector");

// CFG: VERBOSE-LEVEL
$cfg->setConfigEntry('verbose_level', 0);

// CFG: CACHE-TYPE
$cfg->setConfigEntry('cache_class', "MemoryCache");

// CFG: SEARCH-CRITERIA
$cfg->setConfigEntry('search_criteria_class', "SearchCriteria");

// CFG: DATASET-CRITERIA
$cfg->setConfigEntry('dataset_criteria_class', "DataSetCriteria");

// CFG: UPDATE-CRITERIA
$cfg->setConfigEntry('update_criteria_class', "UpdateCriteria");

// CFG: FILE-IO-HANDLER
$cfg->setConfigEntry('file_io_class', "FileIoHandler");

// CFG: FILTER-CHAIN
$cfg->setConfigEntry('filter_chain_class', "FilterChain");

// CFG: FILE-INPUT-STREAM
$cfg->setConfigEntry('file_input_class', "FileIoStream");

// CFG: FILE-OUTPUT-STREAM
$cfg->setConfigEntry('file_output_class', "FileIoStream");

// CFG: EMAIL-VALIDATOR
$cfg->setConfigEntry('email_validator_class', "EmailValidatorFilter");

// CFG: USERNAME-VALIDATOR
$cfg->setConfigEntry('username_validator_class', "UserNameValidatorFilter");

// CFG: USERNAME-IS-GUEST
$cfg->setConfigEntry('username_is_guest_class', "UserNameIsGuestFilter");

// CFG: PASSWORD-VALIDATOR
$cfg->setConfigEntry('password_validator_class', "PasswordValidatorFilter");

// CFG: RULES-ACCEPTED-CLASS
$cfg->setConfigEntry('rules_accepted_class', "RulesAcceptedFilter");

// CFG: USERNAME-VERIFIER-CLASS
$cfg->setConfigEntry('username_verifier_class', "UserNameVerifierFilter");

// CFG: USER-GUEST-VERIFIER-CLASS
$cfg->setConfigEntry('user_guest_verifier_class', "UserGuestVerifierFilter");

// CFG: EMAIL-VERIFIER
$cfg->setConfigEntry('email_verifier_class', "EmailVerifierFilter");

// CFG: PASSWORD-VERIFIER-CLASS
$cfg->setConfigEntry('password_verifier_class', "PasswordVerifierFilter");

// CFG: PASSWD-GUEST-VERIFIER-CLASS
$cfg->setConfigEntry('passwd_guest_verifier_class', "PasswordGuestVerifierFilter");

// CFG: EMAIL-CHANGE-CLASS
$cfg->setConfigEntry('email_change_class', "EmailChangeFilter");

// CFG: PASSWORD-CHANGE-CLASS
$cfg->setConfigEntry('password_change_class', "PasswordChangeFilter");

// CFG: ACCOUNT-PASSWORD-CLASS
$cfg->setConfigEntry('account_password_class', "AccountPasswordVerifierFilter");

// CFG: USER-STATUS-CLASS
$cfg->setConfigEntry('user_status_class', "UserStatusVerifierFilter");

// CFG: USER-UNCONFIRMED-CLASS
$cfg->setConfigEntry('user_unconfirmed_class', "UserUnconfirmedVerifierFilter");

// CFG: CRYPTO-CLASS
$cfg->setConfigEntry('crypto_class', "CryptoHelper");

// CFG: RNG-CLASS
$cfg->setConfigEntry('rng_class', "RandomNumberGenerator");

// CFG: USER-DB-WRAPPER-CLASS
$cfg->setConfigEntry('user_db_wrapper_class', "UserDatabaseWrapper");

// CFG: NEWS-DB-WRAPPER-CLASS
$cfg->setConfigEntry('news_db_wrapper_class', "NewsDatabaseWrapper");

// CFG: WEB-CMD-RESOLVER-CLASS
$cfg->setConfigEntry('web_cmd_resolver_class', "WebCommandResolver");

// CFG: IMAGE-CMD-RESOLVER-CLASS
$cfg->setConfigEntry('image_cmd_resolver_class', "ImageCommandResolver");

// CFG: MAILER-CLASS
$cfg->setConfigEntry('mailer_class', "DebugMailer");

// CFG: MATH-PRIME
$cfg->setConfigEntry('math_prime', 591623);

// CFG: DATE-KEY
$cfg->setConfigEntry('date_key', date("d-m-Y (l-F-T)", time()));

// CFG: SALT-LENGTH
$cfg->setConfigEntry('salt_length', 10);

// CFG: RND-STR-LENGTH
$cfg->setConfigEntry('rnd_str_length', 128);

// CFG: HASH-MASK
$cfg->setConfigEntry('hash_mask', "%1s:%2s:%3s"); // 1=salt, 2=extra salt, 3=plain password

// CFG: IS-SINGLE-SERVER
$cfg->setConfigEntry('is_single_server', "Y");

// CFG: POST-REGISTRATION-ACTION
$cfg->setConfigEntry('post_registration_class', "LoginAfterRegistrationAction");

// CFG: USER-CLASS
$cfg->setConfigEntry('user_class', "Member");

// CFG: GUEST-CLASS
$cfg->setConfigEntry('guest_class', "Guest");

// CFG: COOKIE-EXPIRE
$cfg->setConfigEntry('cookie_expire', (60*60*2)); // Two hours!

// CFG: COOKIE-PATH
$cfg->setConfigEntry('cookie_path', dirname($_SERVER['SCRIPT_NAME']) . "/");

// CFG: COOKIE-DOMAIN
$cfg->setConfigEntry('cookie_domain', $cfg->detectDomain()); // Is mostly the same...

// CFG: COOKIE-SSL
$cfg->setConfigEntry('cookie_ssl', (isset($_SERVER['HTTPS'])));

// CFG: CRYPT-FIXED-SALT
$cfg->setConfigEntry('crypt_fixed_salt', "N");

// CFG: DB-UPDATE-PRIMARY-FORCED
$cfg->setConfigEntry('db_update_primary_forced', "Y");

// CFG: GERMAN-DATE-TIME
$cfg->setConfigEntry('german_date_time', "%3\$s.%2\$s.%1\$s, %4\$s:%5\$s:%6\$s");

// [EOF]
?>
